@@ -15,7 +15,7 @@ from face_recognition.face_recognition_cli import image_files_in_folder
 from rich.progress import track
 from rich import print
 
-IR_DIR = "ir"
+IR_DIR = "infra"
 RGB_DIR = "rgb"
 
 
@@ -49,7 +49,7 @@ def _copy_images_by_dict(
 
 
 def _get_timestamp(name: str) -> str:
-    return name.split("_")[-1].split(".")[0]
+    return name.split("_")[-1].split(".jpg")[0]
 
 
 def _sort_path_by_encodings(
